HaystackOf

Trait HaystackOf 

pub trait HaystackOf<'a, I>: Haystack<'a>
where Self::Slice: HaystackSlice<'a, Item = I>, I: HaystackItem,
{ }
This trait is exactly the same as Haystack, except that it simplifies bounds by requiring that Item = I.

It is also blanket-implemented for all types that implement Haystack<Item = I>.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl<'a, I, T> HaystackOf<'a, I> for T
where I: HaystackItem, T: Haystack<'a>, <T as HaystackIter<'a>>::Slice: HaystackSlice<'a, Item = I>,