pub trait IntoHaystack<'a, H>where
H: Haystack<'a>,{
// Required method
fn into_haystack(self) -> H;
}Expand description
A trait that is responsible for converting a slice into a stateful Haystack, of type H.
The primary intent of this trait is to allow users to avoid creating their own Haystack,
instead passing a slice to methods on Regex.
If creating a new Haystack type, this trait should be implemented manually so that all types
can be inferred properly.
Required Methods
Sourcefn into_haystack(self) -> H
fn into_haystack(self) -> H
Creates a new Haystack from self.